@@ -13,7 +13,7 @@ Modified from http://code.activestate.com/recipes/491261/
 from __future__ import with_statement
 
 __author__ = "dbr/Ben"
-__version__ = "1.2.1"
+__version__ = "1.2.2"
 
 import os
 import time
@@ -26,84 +26,6 @@ from threading import RLock
 
 cache_lock = RLock()
 
-class FileLockException(Exception):
-    pass
-
-class FileLock(object):
-    """ A file locking mechanism that has context-manager support so
-        you can use it in a with statement. This should be relatively cross
-        compatible as it doesn't rely on msvcrt or fcntl for the locking.
-
-        Modified from http://www.evanfosmark.com/2009/01/cross-platform-file-locking-support-in-python/
-    """
-
-    def __init__(self, file_name, timeout=10, delay=.05, lock_folder = False):
-        """ Prepare the file locker. Specify the file to lock and optionally
-            the maximum timeout and the delay between each attempt to lock.
-        """
-        self.is_locked = False
-        if lock_folder:
-            enclosing_dir, dirname = os.path.split(os.path.split(file_name)[0])
-            self.lockfile = os.path.join(enclosing_dir, "%s.lock" % dirname)
-        else:
-            dirname = os.path.split(os.path.abspath(file_name))[0]
-            print file_name
-            self.lockfile = os.path.join(dirname, "%s.lock" % file_name)
-
-        self.file_name = file_name
-        self.timeout = timeout
-        self.delay = delay
-
-    def acquire(self):
-        """ Acquire the lock, if possible. If the lock is in use, it check again
-            every `wait` seconds. It does this until it either gets the lock or
-            exceeds `timeout` number of seconds, in which case it throws
-            an exception.
-        """
-        start_time = time.time()
-        while True:
-            try:
-                self.fd = os.open(self.lockfile, os.O_CREAT|os.O_EXCL|os.O_RDWR)
-                break;
-            except OSError, e:
-                if e.errno != errno.EEXIST:
-                    raise e
-                if (time.time() - start_time) >= self.timeout:
-                    raise FileLockException("Timeout occured.")
-                time.sleep(self.delay)
-        self.is_locked = True
-
-    def release(self):
-        """ Get rid of the lock by deleting the lockfile.
-            When working in a `with` statement, this gets automatically
-            called at the end.
-        """
-        if self.is_locked:
-            os.close(self.fd)
-            os.unlink(self.lockfile)
-            self.is_locked = False
-
-    def __enter__(self):
-        """ Activated when used in the with statement.
-            Should automatically acquire a lock to be used in the with block.
-        """
-        if not self.is_locked:
-            self.acquire()
-        return self
-
-    def __exit__(self, type, value, traceback):
-        """ Activated at the end of the with statement.
-            It automatically releases the lock if it isn't locked.
-        """
-        if self.is_locked:
-            self.release()
-
-    def __del__(self):
-        """ Make sure that the FileLock instance doesn't leave a lockfile
-            lying around.
-        """
-        self.release()
-
 def locked_function(origfunc):
     """Decorator to execute function under lock"""
     def wrapped(*args, **kwargs):
@@ -178,9 +100,18 @@ class CacheHandler(urllib2.BaseHandler):
         """The location of the cache directory"""
         self.max_age = max_age
         self.cache_location = cache_location
-        with FileLock(self.cache_location, lock_folder = True):
-            if not os.path.exists(self.cache_location):
+        if not os.path.exists(self.cache_location):
+            try:
                 os.mkdir(self.cache_location)
+            except OSError, e:
+                if e.errno == errno.EEXIST and os.path.isdir(self.cache_location):
+                    # File exists, and it's a directory,
+                    # another process beat us to creating this dir, that's OK.
+                    pass
+                else:
+                    # Our target dir is already a file, or different error,
+                    # relay the error!
+                    raise
 
     def default_open(self, request):
         """Handles GET requests, if the response is cached it returns it
